Welcome to MRdataset's documentation!
======================================

.. toctree::
   :maxdepth: 2
   :caption: Tutorials

   installation
   readme

.. toctree::
   :maxdepth: 2
   :caption: How-to Guides & Examples

   contributing

.. toctree::
   :maxdepth: 2
   :caption: Reference

   modules

.. toctree::
   :maxdepth: 2
   :caption: Background

   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
